@@ -663,6 +663,32 @@ class ApiField:
     """"""
     QUALITY_CHECK_USER_IDS = "qualityCheckUserIds"
     """"""
+    EMBEDDINGS = "embeddings"
+    """"""
+    EMBEDDINGS_ENABLED = "embeddingsEnabled"
+    """"""
+    EMBEDDINGS_UPDATED_AT = "embeddingsUpdatedAt"
+    """"""
+    EMBEDDINGS_IN_PROGRESS = "embeddingsInProgress"
+    """"""
+    AI_SEARCH_KEY = "aiSearchKey"
+    """"""
+    AI_SEARCH_META = "aiSearchMeta"
+    """"""
+    ENTITY_ITEMS = "entityItems"
+    """"""
+    SCORE = "score"
+    """"""
+    HARD_DELETE = "hardDelete"
+    """"""
+    THRESHOLD = "threshold"
+    """"""
+    THRESHOLD_DIRECTION = "thresholdDirection"
+    """"""
+    METHOD = "method"
+    """"""
+    PROMPT = "prompt"
+    """"""
     UPDATE_STRATEGY = "updateStrategy"
     """"""
 
