@@ -36,6 +36,12 @@ def _int_from_env(value):
     return int(value)
 
 
+def _parse_list_from_env(value: str) -> List[str]:
+    import ast
+
+    return [str(x).strip() for x in ast.literal_eval(value)]
+
+
 def _parse_from_env(
     name: str,
     keys: List[str],
@@ -214,6 +220,32 @@ def team_files_folder(raise_not_found: Optional[bool] = True) -> str:
     )
 
 
+def team_files_folders(raise_not_found: Optional[bool] = True) -> List[str]:
+    """Returns paths to the team files folders from environment variable using following keys:
+        - CONTEXT_SLYFOLDERS
+        - context.slyFolders
+        - modal.state.slyFolders
+        - FOLDERS
+    NOTE: same as team_files_folders
+    :param raise_not_found: if True, raises KeyError if team files folders are not found in environment variables
+    :type raise_not_found: Optional[bool]
+    :return: path to the team files folders
+    :rtype: str
+    """
+    return _parse_from_env(
+        name="team_files_folders",
+        keys=[
+            "CONTEXT_SLYFOLDERS",
+            "context.slyFolders",
+            "modal.state.slyFolders",
+            "FOLDERS",
+        ],
+        postprocess_fn=_parse_list_from_env,
+        default=[],
+        raise_not_found=raise_not_found,
+    )
+
+
 def folder(raise_not_found: Optional[bool] = True) -> str:
     """Returns path to the team files folder from environment variable using following keys:
         - CONTEXT_SLYFOLDER
@@ -229,6 +261,21 @@ def folder(raise_not_found: Optional[bool] = True) -> str:
     return team_files_folder(raise_not_found)
 
 
+def folders(raise_not_found: Optional[bool] = True) -> List[str]:
+    """Returns paths to the team files folders from environment variable using following keys:
+        - CONTEXT_SLYFOLDERS
+        - context.slyFolders
+        - modal.state.slyFolders
+        - FOLDERS
+    NOTE: Same as team_files_folders
+    :param raise_not_found: if True, raises KeyError if team files folders are not found in environment variables
+    :type raise_not_found: Optional[bool]
+    :return: path to the team files folders
+    :rtype: str
+    """
+    return team_files_folders(raise_not_found)
+
+
 def team_files_file(raise_not_found: Optional[bool] = True) -> str:
     """Returns path to the file in the team files from environment variable using following keys:
         - CONTEXT_SLYFILE
@@ -251,6 +298,28 @@ def team_files_file(raise_not_found: Optional[bool] = True) -> str:
     )
 
 
+def team_files_files(raise_not_found: Optional[bool] = True) -> List[str]:
+    """Returns paths to the files in the team files from environment variable using following keys:
+        - CONTEXT_SLYFILES
+        - context.slyFiles
+        - modal.state.slyFiles
+        - FILES
+
+    NOTE: same as team_files_file
+    :param raise_not_found: if True, raises KeyError if file is not found in environment variables
+    :type raise_not_found: Optional[bool]
+    :return: path to the file in the team files
+    :rtype: str
+    """
+    return _parse_from_env(
+        name="team_files_files",
+        keys=["CONTEXT_SLYFILES", "context.slyFiles", "modal.state.slyFiles", "FILES"],
+        postprocess_fn=_parse_list_from_env,
+        default=[],
+        raise_not_found=raise_not_found,
+    )
+
+
 def server_address(raise_not_found: Optional[bool] = True) -> str:
     """Returns server address from environment variable using following keys:
         - SERVER_ADDRESS
@@ -321,6 +390,22 @@ def file(raise_not_found: Optional[bool] = True) -> str:
     return team_files_file(raise_not_found)
 
 
+def files(raise_not_found: Optional[bool] = True) -> List[str]:
+    """Returns paths to the files in the team files from environment variable using following keys:
+        - CONTEXT_SLYFILES
+        - context.slyFiles
+        - modal.state.slyFiles
+        - FILES
+
+    NOTE: Same as team_files_files
+    :param raise_not_found: if True, raises KeyError if file is not found in environment variables
+    :type raise_not_found: Optional[bool]
+    :return: path to the file in the team files
+    :rtype: str
+    """
+    return team_files_files(raise_not_found)
+
+
 def task_id(raise_not_found: Optional[bool] = True) -> int:
     """Returns task id from environment variable using following keys:
         - TASK_ID
